from typing import TypedDict, Optional, Dict, Any

from datacaster.classes import CastDataClass


class GroupData(CastDataClass):
    description: str
    display_name: str
    mail_enabled: bool
    object_id: str
    object_type: str
    security_enabled: bool


class Group(TypedDict):
    """
    - Contains information about an Azure AD Group

    !!! info "AD Group Keys"

        __description__: The group description

        __display_name__:  Group display name (not unique)

        __mail_enabled__: Indicates whether the group is mail enabled

        __object_id__: Group object ID

        __object_type__: The type of the object (`Group`)

        __security_enabled__: Indicates whether the group is security enabled

    """

    __annotations__ = GroupData.__dict__["__annotations__"]


class UserData(CastDataClass):
    account_enabled: bool
    given_name: str
    mail: str
    mail_nickname: str
    display_name: str
    object_id: str
    object_type: str
    user_principal_name: str
    surname: str
    usage_location: str


class User(TypedDict):
    """
    - Contains information about an Azure AD User

    !!! info "AD User Keys"

        __account_enabled__: Denotes whether the user is enabled

        __display_name__:  User display name (not unique)

        __given_name__: The user's given name

        __mail__: User email address

        __mail_nickname__: User email alias

        __object_id__: User object ID

        __object_type__: The type of the object (`User`)

        __user_principal_name__: User principal name

        __surname__: The user's surname

        __usage_location__: A two letter country code (ISO standard 3166)

    """

    __annotations__ = UserData.__dict__["__annotations__"]


class UserUpdateDict(TypedDict):
    usage_location: Optional[str] = None
    given_name: Optional[str] = None
    surname: Optional[str] = None
    account_enabled: Optional[bool] = None
    display_name: Optional[str] = None
    user_principal_name: Optional[str] = None
    mail_nickname: Optional[str] = None
    additional_properties: Optional[Dict[str, Any]] = None
