from typing import TypedDict


class AzureClient(TypedDict):
    """
    - Contains Azure authentication details using a service principal

    - It is used as an _input_ to many of the actions in this plugin

    !!! tip "Generating API Access Keys"

        See this [Azure article](https://docs.microsoft.com/en-us/azure/active-directory/develop/howto-create-service-principal-portal) for information about creating a service principal.

    !!! warning "Supplying Credentials"

        You should ___always___ use a PPA Vault integration to provide credentials to a plugin action.

    !!! danger "Required Keys"

        __tenant_id__: Azure Tenant ID

        __client_id__: Azure Client ID

        __client_secret__: Azure Client Secret

    !!! example

        ```yaml linenums="1"
        azure_client:
          tenant_id: your_tenant_id
          client_id: your_client_id
          client_secret: your_client_secret
        ```

    """

    tenant_id: str
    client_id: str
    client_secret: str
